==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/encryption_otr/translations/encryption_otr_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create private key started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unverified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not Private</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 question:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/encryption_otr/translations/encryption_otr_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
